@@ -1,13 +1,14 @@
 import atexit
 import base64
 import datetime
+import os
+import re
 import signal
+import socket
 import subprocess
 import sys
 import time
 import uuid
-import re
-import os
 from itertools import chain
 from pathlib import Path
 
@@ -16,27 +17,29 @@ import clickclick
 import humanize
 import requests
 import yaml
-from clickclick import Action, info, print_table
-from dateutil.parser import parse
-from dateutil.tz import tzutc
-
 import zalando_kubectl
 import zalando_kubectl.kube_permissions
 import zalando_kubectl.secrets
 import zalando_kubectl.traffic
+from clickclick import Action, info, print_table
+from dateutil.parser import parse
+from dateutil.tz import tzutc
 from zalando_kubectl.models.deployment import Deployment
 from zalando_kubectl.models.stackset_ingress_authoritative import StackSetIngressAuthoritative
 from zalando_kubectl.utils import (
-    auth_token,
-    auth_headers,
-    get_api_server_url,
-    current_user,
-    Environment,
     DecoratingGroup,
+    Environment,
     PortMappingParamType,
+    auth_headers,
+    auth_token,
+    current_user,
+    get_api_server_url,
 )
-from . import access_request, kube_config, registry, completion as comp
-from .templating import read_senza_variables, prepare_variables, copy_template
+
+from . import access_request
+from . import completion as comp
+from . import kube_config, registry
+from .templating import copy_template, prepare_variables, read_senza_variables
 
 UPDATE_BLOCK_CONFIG_ITEM = "cluster_update_block"
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
@@ -549,6 +552,12 @@ def tunnel(env: Environment, address, target, ports):
         $ zkubectl tunnel TARGET [LOCAL_PORT:]REMOTE_PORT [...[LOCAL_PORT_N:]REMOTE_PORT_N]
     """
 
+    # Check if local ports are already in use
+    for i, port in enumerate(ports):
+        with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
+            if s.connect_ex(("localhost", int(port[0]))) == 0:
+                raise click.UsageError("Port {} already in use".format(port[0]))
+
     # the name of the job is different for each invocation
     # it gets cleaned up when the command exists
     job_name = "port-forwarder-{}".format(uuid.uuid4())
@@ -805,7 +814,7 @@ def request_cluster_access(env: Environment, emergency, incident, user, reason):
 
 def make_emergency_access_request(config, incident, user, reason):
     user = access_request_username(user)
-    reference_url = "https://techjira.zalando.net/browse/INC-{}".format(incident) if incident else None
+    reference_url = "https://jira.zalando.net/browse/INC-{}".format(incident) if incident else None
     access_request.create(config, "emergency", reference_url, user, " ".join(reason))
     click.echo(
         "Emergency access provisioned for {}. Note that it might take a while "
